**************************************************************************
* Question 12.2 for Friberg: "Managing risk and uncertainty" 
* stata do-file
* Playing with profits in the Chang and Harrington (JEMS, 1996) framework
**************************************************************************  

clear all
cd "X:\Users\nerf\Documents\forskning\aktiva\risk_uncertainty_book\exercizes\ch12" /*replace this with your own directory where data is stored*/

* gen the random shocks
quietly set obs 1000      /*add obs for counterfactual*/
set seed 10101            /* set up the random numbers generator*/  
generate eta_i=rnormal(0,0.2)         /* generate cost shock for i*/
generate eta_j=rnormal(0,0.2)         /* generate cost shock for j*/
* define parameters
gen alfa=10
gen beta=2 
gen chat=0.6

********************************************************************
* Now turn to prices and profits in the different cases
********************************************************************
* first a high gamma=> low differentiation 
gen gamma=8
gen pstar_i=alfa/(2*beta+gamma)+0.5*(chat+eta_i)+0.5*gamma^2/(4*(beta+gamma)^2-gamma^2)*chat+gamma*(beta+gamma)*chat/(4*(beta+gamma)^2-gamma^2)
gen pstar_j=alfa/(2*beta+gamma)+0.5*(chat+eta_j)+0.5*gamma^2/(4*(beta+gamma)^2-gamma^2)*chat+gamma*(beta+gamma)*chat/(4*(beta+gamma)^2-gamma^2)
gen profit_i_gh=(alfa-beta*pstar_i-gamma*(pstar_i-pstar_j))*(pstar_i-(chat+eta_i)) 
gen profit_j_gh=(alfa-beta*pstar_j-gamma*(pstar_j-pstar_i))*(pstar_j-(chat+eta_j))
twoway scatter profit_i_gh profit_j_gh, saving(gamma_high, replace)
kdensity profit_i_gh, xtitle (gamma_high) saving(dens_gamma_high, replace)
scatter profit_i_gh eta_i, saving(scatter_gamma_high, replace)


* then a high differentiation case
* redo analysis for gamma=0
drop pstar_i pstar_j gamma 
gen gamma=0
gen pstar_i=alfa/(2*beta+gamma)+0.5*(chat+eta_i)+0.5*gamma^2/(4*(beta+gamma)^2-gamma^2)*chat+gamma*(beta+gamma)*chat/(4*(beta+gamma)^2-gamma^2)
gen pstar_j=alfa/(2*beta+gamma)+0.5*(chat+eta_j)+0.5*gamma^2/(4*(beta+gamma)^2-gamma^2)*chat+gamma*(beta+gamma)*chat/(4*(beta+gamma)^2-gamma^2)
gen profit_i_gl=(alfa-beta*pstar_i-gamma*(pstar_i-pstar_j))*(pstar_i-(chat+eta_i)) 
gen profit_j_gl=(alfa-beta*pstar_j-gamma*(pstar_j-pstar_i))*(pstar_j-(chat+eta_j))
twoway scatter profit_i_gl profit_j_gl, saving(gamma_low, replace)
kdensity profit_i_gl, xtitle (gamma_low) saving(dens_gamma_low, replace)
scatter profit_i_gl eta_i, saving(scatter_gamma_low, replace)

* and finally an intermediate case
* redo analysis for gamma=1
drop pstar_i pstar_j gamma 
gen gamma=1.9
gen pstar_i=alfa/(2*beta+gamma)+0.5*(chat+eta_i)+0.5*gamma^2/(4*(beta+gamma)^2-gamma^2)*chat+gamma*(beta+gamma)*chat/(4*(beta+gamma)^2-gamma^2)
gen pstar_j=alfa/(2*beta+gamma)+0.5*(chat+eta_j)+0.5*gamma^2/(4*(beta+gamma)^2-gamma^2)*chat+gamma*(beta+gamma)*chat/(4*(beta+gamma)^2-gamma^2)
gen profit_i_gm=(alfa-beta*pstar_i-gamma*(pstar_i-pstar_j))*(pstar_i-(chat+eta_i)) 
gen profit_j_gm=(alfa-beta*pstar_j-gamma*(pstar_j-pstar_i))*(pstar_j-(chat+eta_j))
twoway scatter profit_i_gm profit_j_gm, saving(gamma_medium, replace)
kdensity profit_i_gm, xtitle (gamma_medium) saving(dens_gamma_medium, replace)
scatter profit_i_gm eta_i, saving(scatter_gamma_medium, replace)

* question a)
tabstat profit_i_gh profit_i_gm profit_i_gl, stat(mean p50 sd min max)
* lower means and higher standard deviations when less differentiated are the typical results
* chang and harrington show that starting from gamma=0 profits at first increase as gamma is raised
* for the current parameter values this only applies for a very low range 

* question b)
* combine the graphs where profits for firm i plotted againts profits for firm j
graph combine "gamma_high" "gamma_medium" "gamma_low", title("Profits in Chang and Harrington under different levels of gamma", style(textbookstyle)) saving(gammas, replace asis)

* question c)
* combine the graphs where profits for firm i plotted againts mc firm i
graph combine "scatter_gamma_high" "scatter_gamma_medium" "scatter_gamma_low", , title("Profits as a function of mc under different levels of gamma", style(textbookstyle)) saving(gammas, replace asis)


 

