****************************************************************************************
* Q14_2. Friberg: Managing risk and uncertainty
* stata do-file
* This question uses data from Friberg and Grnqvist (2012), see also website of AEJ: Applied
* data aggregated to yearly level 
****************************************************************************************
clear all
cd "X:\Users\nerf\Documents\forskning\aktiva\risk_uncertainty_book\exercizes\ch14" /*replace this with your own directory where data is stored*/
use q14_2, clear


* create variables needed for logit
* set total market the same as in France, 46.8 liters per household
gen tot_year=4600000*46.8     /*total market*/
gen ms=liters_id_year/tot_year  /*market share of total market*/
bysort year: egen liters_year=sum(liters_id_year) /*total sales of wine per year*/
gen mso=liters_year/tot_year    /*market share of outside good*/
gen dep=ln(ms)-ln(mso)           /*the dependent variable*/

*generate a BLP instrument
bysort taste_segment year: egen sumgrade=sum(v10_aomm) /*BLP instruments are functions of charactersitics of products in the market, here sum of grades in reviews*/

sort artikelnr year
tsset artikelnr year /*declare the data as time series*/

* question a)
xi: reg dep price_year v10_aomm ma_split i.dist i.country i.year i.segm if year<2006

* question b)
xi: ivregress 2sls dep (price_year = sumgrade seksource) ma_split v10_aomm i.dist i.country i.year i.segm if year<2006

predict dep_base  /*predict dependent variable*/
predict ksi, resid /*predict ksi, the "unobserved product quality" which is equal to the error term in the regression */

* question c)
replace _Idist_6=0 if artikelnr==631101  /*change distribution level for Stoneleigh*/
replace _Idist_5=1 if artikelnr==631101
predict dep_counter                       /*predict counterfactual dependent variable*/
* now calculate counterfactual market shares using expression for delta on page 268
* and market share equation on page 271
gen dep_counter_wksi=dep_counter+ksi      /*add the "unobserved product quality" to determine delta*/
gen count_d=exp(dep_counter_wksi)  
bysort year: egen count_all=sum(count_d)
gen count_ms=count_d/count_all
gen count_liter=count_ms*tot_year  /*generate counterfactual liters sold with lower distribution*/
sum count_liter liters_id_year if artikelnr==631101&year==2006

*************************************************
* NOW TURN TO APPLICATION AS IN FIGURES 14.6 AND 14.7
 
* Consider a potential change in the retailer markup
* price to consumer=price to wholesale*1.2208*1.23*1.25+3.85 
* where 22.08 is alcohol tax (per liter, not ad valorem), 23 is retailer markup (lowered to 19 in august 2006)
* 25 is VAT and 3.85 is per liter markup (2.70 kr per bottle of 70 cl: 27kr/7liters) 
* Note we keep the wholesale price constant and assume full pass-through of change into consumer price
gen price_wholesale=(price_year-3.85)/(1.2208*1.23*1.25)
gen new_price=price_wholesale*(1.2208*1.19*1.25)+5
gen old_price=price_year		
replace price_year=new_price		/* and replace for prediction purposes*/
predict dep_dlow_np		            
* predict market shares and liters sold for low store coverage and low retail markups using expression for delta on page 268
*and market share equation on page 271
gen delta_dlow_np=dep_dlow_np+ksi
gen e_delta_dlow_np=exp(delta_dlow_np)
bysort year: egen all_delta_dlow_np=sum(e_delta_dlow_np)
gen ms_dlow_np=e_delta_dlow_np/all_delta_dlow_np
scatter ms_dlow_np ms 
gen liter_dlow_np=ms_dlow_np*tot_year
sum liter_dlow_np liter_dlow liters_id_year if artikelnr==631101&year==2006
sum new_price if artikelnr==631101&year==2006

* and then finally one case with new prices but higher store coverage
replace _Idist_6=1 if artikelnr==631101
replace _Idist_5=0 if artikelnr==631101
* again predict market shares and liters sold expression for delta on page 268
*and market share equation on page 271
predict dep_np
gen delta_np=dep_np+ksi
gen e_delta_np=exp(delta_np)
bysort year: egen all_delta_np=sum(e_delta_np)
gen ms_np=e_delta_np/all_delta_np
scatter ms_np ms 
gen liter_np=ms_np*tot_year
sum liter_np liter_dlow_np liter_dlow liters_id_year if artikelnr==631101&year==2006
sum new_price if artikelnr==631101&year==2006

*************************************************
* Now turn to Monte-Carlo, in more advanced applications can have interactions between the simulations and prices, as in Friberg and Ganslandt (Journal of Finance, 2007)
clear
* do one with normal
quietly set obs 1000
set seed 10101
generate count_seknzd=rnormal(5.695,0.197)   /* generate counterfactual draws, mean equal to 2005 value and sd equal to historical*/
hist count_seknzd

* profits for stoneleigh when distributed in all stores
* average price in unit value import data in imports of bottled white wine from NZ is around 50 sek per liter
* which translates into a price of around 9 NZD per liter. keep this fixed
* prices and sales from simulations above
gen allstores_oldprice=(68.27-count_seknzd*9)*413403  /*68.27 is wholesale price as calculated above, 413403 is counterfactual liters from above*/
gen allstores_newprice=(68.27-count_seknzd*9)*445347
gen fewerstores_oldprice=(68.27-count_seknzd*9)*256936
gen fewerstores_newprice=(68.27-count_seknzd*9)*264300

* figure 14.6
twoway kdensity allstores_oldprice||kdensity allstores_newprice, lpattern(dash)||kdensity fewerstores_oldprice||(kdensity fewerstores_newprice, lpattern(dash)), graphregion(fcolor(white) color(white)) xtitle("Profits in SEK") ylabel(#3) legend(on order(1 "All stores old markup" 2 "All stores new markup" 3 "Fewer stores old markup" 4 "Fewer stores new markup"))

* figure 14_7
twoway kdensity allstores_oldprice, graphregion(fcolor(white) color(white)) xtitle("Profits in SEK") ylabel(#3) legend(on order(1 "All stores old markup"))
* 14.7a
twoway kdensity allstores_newprice, graphregion(fcolor(white) color(white)) xtitle("Profits in SEK") ylabel(#3) legend(on order(1 "All stores new markup" ))
*14_7b
twoway kdensity fewerstores_oldprice, graphregion(fcolor(white) color(white)) xtitle("Profits in SEK") ylabel(#3) legend(on order(1 "Fewer stores old markup"))
*14_7c
twoway kdensity fewerstores_newprice , graphregion(fcolor(white) color(white)) xtitle("Profits in SEK") ylabel(#3) legend(on order(1 "Fewer stores new markup"))





